@@ -1,6 +1,8 @@
 context("PlotCatalog.IndelCatalog")
 
 test_that("PlotCatalog.IndelCatalog function", {
+  skip_if("" == system.file(package = "BSgenome.Hsapiens.1000genomes.hs37d5"))
+  stopifnot(requireNamespace("BSgenome.Hsapiens.1000genomes.hs37d5"))
   opar <- par(mar = c(2, 2, 2, 1))
   on.exit(par(opar))
   catalog <- ReadCatalog("testdata/BTSG_WGS_PCAWG.indels.csv",
