@@ -1,6 +1,8 @@
 context("PlotCatalog.SBS1536Catalog")
 
 test_that("PlotCatalog.SBS1536Catalog function", {
+  skip_if("" == system.file(package = "BSgenome.Hsapiens.1000genomes.hs37d5"))
+  stopifnot(requireNamespace("BSgenome.Hsapiens.1000genomes.hs37d5"))
   catalog.counts <-
     ReadCatalog("testdata/regress.cat.sbs.1536.csv", ref.genome = "GRCh37",
                 region = "genome", catalog.type = "counts")
